"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fastify_plugin_1 = require("fastify-plugin");
const graphql_1 = require("graphql");
const postgraphile_1 = require("postgraphile");
const create_pool_1 = require("./create-pool");
const schema_1 = require("./schema");
const QueryPerformer_1 = require("./QueryPerformer");
module.exports = fastify_plugin_1.default(async function (fastify, opts) {
    const pool = create_pool_1.createPool(opts.pool);
    if (opts.middleware) {
        withMiddleware(fastify, pool, opts.schemas, opts.postgraphileOptions);
        return;
    }
    const schema = await schema_1.createSchema(postgraphile_1.createPostGraphileSchema, pool, opts.schemas);
    const queryPerformer = new QueryPerformer_1.QueryPerformer(schema, graphql_1.graphql, postgraphile_1.withPostGraphileContext, pool, opts.contextOptions);
    fastify.decorateReply('graphql', queryPerformer.perform.bind(queryPerformer));
}, { fastify: '3.x' });
function withMiddleware(fastify, pool, schemas, postgraphileOptions) {
    const middleware = postgraphile_1.postgraphile(pool, schemas, postgraphileOptions);
    const convertHandler = (handler) => async (req, reply) => await handler(new postgraphile_1.PostGraphileResponseFastify3(req, reply));
    fastify.options(middleware.graphqlRoute, convertHandler(middleware.graphqlRouteHandler));
    fastify.post(middleware.graphqlRoute, convertHandler(middleware.graphqlRouteHandler));
    if (middleware.options.graphiql !== undefined && middleware.options.graphiql !== null) {
        if (middleware.graphiqlRouteHandler !== undefined && middleware.graphiqlRouteHandler !== null) {
            fastify.head(middleware.graphiqlRoute, convertHandler(middleware.graphiqlRouteHandler));
            fastify.get(middleware.graphiqlRoute, convertHandler(middleware.graphiqlRouteHandler));
        }
    }
}
